/* Request field */
QTextEdit {
    color: #fbfaf5;
}
/* Buttons within messages */
QLabel > QPushButton {
    background-color: none;
}
/* Token usage labels by id */
QLabel#ai_assistant_dialog_usage_module_name_label,
QLabel#ai_assistant_dialog_usage_model_name_label,
QLabel#ai_assistant_dialog_usage_tokens_label {
    color: #666666;
}
/* Request submit button */
QPushButton {
    color: #fbfaf5;
    background-color: #660000;
}
QPushButton:disabled {
    background-color: #330000;
}