# Latin lexemes statusbar.py
lexemes = {
    "statusbar_path_home_label": "Domus fasciculus notarum",
    "statusbar_path_home_accessible_name": "Naviga ad domum fasciculi notarum",
    "statusbar_litter_bin_label": "Fiscina",
    "statusbar_litter_bin_accessible_name": "Ostendere contentum fiscinae",

    "statusbar_save_progress_label": b'\xf0\x9f\x92\xbe',
    "statusbar_encryption_symbol_encrypted_label": b'\xf0\x9f\x94\x92',
    "statusbar_encryption_symbol_unencrypted_label": b'\xf0\x9f\x94\x93',

    "statusbar_mode_label_mode_view": "Modus Visum",
    "statusbar_mode_label_mode_edit": "Modus Editio",
    "statusbar_mode_label_mode_source": "Modus Fons",

    "statusbar_source_label_source_markdown": "Markdown",
    "statusbar_source_label_source_html": "HTML",

    "statusbar_encryption_label": "{encryption} {icon}",
    "statusbar_encryption_label_encryption_plain": "Simplicitas",
    "statusbar_encryption_label_encryption_encrypted": "Cryptatus",

    "statusbar_cursor_label": "linea: {line} → columna: {column}",
    "statusbar_cursor_label_selected": "linea: {line} → columna: {column} → selectus: {selected}",
    "statusbar_cursor_label_with_global": "linea: {line} → columna: {column} → positio: {position}",
    "statusbar_cursor_label_selected_with_global":
        "linea: {line} → columna: {column} → positio: {position} → selectus: {selected}",
}
