# Finnish lexemes statusbar.py
lexemes = {
    "statusbar_path_home_label": "Muistiinpanojen kotikansio",
    "statusbar_path_home_accessible_name": "Siirry muistiinpanojen kotikansioon",
    "statusbar_litter_bin_label": "Roskakori",
    "statusbar_litter_bin_accessible_name": "Näytä roskakorin sisältö",

    "statusbar_save_progress_label": b'\xf0\x9f\x92\xbe',  # Emoji for floppy disk (save icon)
    "statusbar_encryption_symbol_encrypted_label": b'\xf0\x9f\x94\x92',  # Emoji for locked padlock (encrypted)
    "statusbar_encryption_symbol_unencrypted_label": b'\xf0\x9f\x94\x93',  # Emoji for unlocked padlock (unencrypted)

    "statusbar_mode_label_mode_view": "Katselutila",
    "statusbar_mode_label_mode_edit": "Muokkaustila",
    "statusbar_mode_label_mode_source": "Lähdetila",

    "statusbar_source_label_source_markdown": "Markdown",
    "statusbar_source_label_source_html": "HTML",

    "statusbar_encryption_label": "{encryption} {icon}",
    "statusbar_encryption_label_encryption_plain": "Salaamaton",
    "statusbar_encryption_label_encryption_encrypted": "Salattu",

    "statusbar_cursor_label": "rivi: {line} → sar: {column}",
    "statusbar_cursor_label_selected": "rivi: {line} → sar: {column} → val: {selected}",
    "statusbar_cursor_label_with_global": "rivi: {line} → sar: {column} → pos: {position}",
    "statusbar_cursor_label_selected_with_global": "rivi: {line} → sar: {column} → pos: {position} → val: {selected}",
}
