# Chinese lexemes statusbar.py
lexemes = {
    "statusbar_path_home_label": "笔记主文件夹",
    "statusbar_path_home_accessible_name": "导航到笔记主文件夹",
    "statusbar_litter_bin_label": "垃圾箱",
    "statusbar_litter_bin_accessible_name": "显示垃圾箱内容",

    "statusbar_save_progress_label": b'\xf0\x9f\x92\xbe',
    "statusbar_encryption_symbol_encrypted_label": b'\xf0\x9f\x94\x92',
    "statusbar_encryption_symbol_unencrypted_label": b'\xf0\x9f\x94\x93',

    "statusbar_mode_label_mode_view": "查看模式",
    "statusbar_mode_label_mode_edit": "编辑模式",
    "statusbar_mode_label_mode_source": "源代码模式",

    "statusbar_source_label_source_markdown": "Markdown",
    "statusbar_source_label_source_html": "HTML",

    "statusbar_encryption_label": "{encryption} {icon}",
    "statusbar_encryption_label_encryption_plain": "明文",
    "statusbar_encryption_label_encryption_encrypted": "加密",

    "statusbar_cursor_label": "行: {line} → 列: {column}",
    "statusbar_cursor_label_selected": "行: {line} → 列: {column} → 选: {selected}",
    "statusbar_cursor_label_with_global": "行: {line} → 列: {column} → 位: {position}",
    "statusbar_cursor_label_selected_with_global": "行: {line} → 列: {column} → 位: {position} → 选: {selected}",
}
