# Russian lexemes statusbar.py
lexemes = {
    "statusbar_path_home_label": "Домашняя папка заметок",
    "statusbar_path_home_accessible_name": "Перейти в домашнюю папку заметок",
    "statusbar_litter_bin_label": "Корзина",
    "statusbar_litter_bin_accessible_name": "Показать содержимое корзины",

    "statusbar_save_progress_label": b'\xf0\x9f\x92\xbe',
    "statusbar_encryption_symbol_encrypted_label": b'\xf0\x9f\x94\x92',
    "statusbar_encryption_symbol_unencrypted_label": b'\xf0\x9f\x94\x93',

    "statusbar_mode_label_mode_view": "Режим просмотра",
    "statusbar_mode_label_mode_edit": "Режим редактирования",
    "statusbar_mode_label_mode_source": "Режим источника",

    "statusbar_source_label_source_markdown": "Markdown",
    "statusbar_source_label_source_html": "HTML",

    "statusbar_encryption_label": "{encryption} {icon}",
    "statusbar_encryption_label_encryption_plain": "Обычный",
    "statusbar_encryption_label_encryption_encrypted": "Зашифрованный",

    "statusbar_cursor_label": "строка: {line} → столбец: {column}",
    "statusbar_cursor_label_selected": "строка: {line} → столбец: {column} → выбр: {selected}",
    "statusbar_cursor_label_with_global": "строка: {line} → столбец: {column} → поз: {position}",
    "statusbar_cursor_label_selected_with_global":
        "строка: {line} → столбец: {column} → поз: {position} → выбр: {selected}",
}
