# Korean lexemes statusbar.py
lexemes = {
    "statusbar_path_home_label": "노트 홈 폴더",
    "statusbar_path_home_accessible_name": "노트 홈 폴더로 이동",
    "statusbar_litter_bin_label": "휴지통",
    "statusbar_litter_bin_accessible_name": "휴지통 내용 보기",

    "statusbar_save_progress_label": b'\xf0\x9f\x92\xbe',
    "statusbar_encryption_symbol_encrypted_label": b'\xf0\x9f\x94\x92',
    "statusbar_encryption_symbol_unencrypted_label": b'\xf0\x9f\x94\x93',

    "statusbar_mode_label_mode_view": "보기 모드",
    "statusbar_mode_label_mode_edit": "편집 모드",
    "statusbar_mode_label_mode_source": "소스 모드",

    "statusbar_source_label_source_markdown": "Markdown",
    "statusbar_source_label_source_html": "HTML",

    "statusbar_encryption_label": "{encryption} {icon}",
    "statusbar_encryption_label_encryption_plain": "일반",
    "statusbar_encryption_label_encryption_encrypted": "암호화됨",

    "statusbar_cursor_label": "줄: {line} → 열: {column}",
    "statusbar_cursor_label_selected": "줄: {line} → 열: {column} → 선택: {selected}",
    "statusbar_cursor_label_with_global": "줄: {line} → 열: {column} → 위치: {position}",
    "statusbar_cursor_label_selected_with_global": "줄: {line} → 열: {column} → 위치: {position} → 선택: {selected}",
}
