# German lexemes statusbar.py
lexemes = {
    "statusbar_path_home_label": "Notizen-Startordner",
    "statusbar_path_home_accessible_name": "Zum Startordner der Notizen navigieren",
    "statusbar_litter_bin_label": "Papierkorb",
    "statusbar_litter_bin_accessible_name": "Inhalt des Papierkorbs anzeigen",

    "statusbar_save_progress_label": b'\xf0\x9f\x92\xbe',
    "statusbar_encryption_symbol_encrypted_label": b'\xf0\x9f\x94\x92',
    "statusbar_encryption_symbol_unencrypted_label": b'\xf0\x9f\x94\x93',

    "statusbar_mode_label_mode_view": "Ansichtsmodus",
    "statusbar_mode_label_mode_edit": "Bearbeitungsmodus",
    "statusbar_mode_label_mode_source": "Quellmodus",

    "statusbar_source_label_source_markdown": "Markdown",
    "statusbar_source_label_source_html": "HTML",

    "statusbar_encryption_label": "{encryption} {icon}",
    "statusbar_encryption_label_encryption_plain": "Klar",
    "statusbar_encryption_label_encryption_encrypted": "Verschlüsselt",

    "statusbar_cursor_label": "Zeile: {line} → Sp: {column}",
    "statusbar_cursor_label_selected": "Zeile: {line} → Sp: {column} → Ausw: {selected}",
    "statusbar_cursor_label_with_global": "Zeile: {line} → Sp: {column} → Pos: {position}",
    "statusbar_cursor_label_selected_with_global": "Zeile: {line} → Sp: {column} → Pos: {position} → Ausw: {selected}",
}
